@@ -3,6 +3,7 @@ package yandex
 import (
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"io"
 	"log"
@@ -13,7 +14,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/pkg/errors"
 	"github.com/rclone/rclone/backend/yandex/api"
 	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/fs/config"
@@ -66,6 +66,11 @@ func init() {
 			})
 		},
 		Options: append(oauthutil.SharedOptions, []fs.Option{{
+			Name:     "hard_delete",
+			Help:     "Delete files permanently rather than putting them into the trash.",
+			Default:  false,
+			Advanced: true,
+		}, {
 			Name:     config.ConfigEncoding,
 			Help:     config.ConfigEncodingHelp,
 			Advanced: true,
@@ -79,8 +84,9 @@ func init() {
 
 // Options defines the configuration for this backend
 type Options struct {
-	Token string               `config:"token"`
-	Enc   encoder.MultiEncoder `config:"encoding"`
+	Token      string               `config:"token"`
+	HardDelete bool                 `config:"hard_delete"`
+	Enc        encoder.MultiEncoder `config:"encoding"`
 }
 
 // Fs represents a remote yandex
@@ -249,7 +255,7 @@ func NewFs(ctx context.Context, name, root string, m configmap.Mapper) (fs.Fs, e
 
 	token, err := oauthutil.GetToken(name, m)
 	if err != nil {
-		return nil, errors.Wrap(err, "couldn't read OAuth token")
+		return nil, fmt.Errorf("couldn't read OAuth token: %w", err)
 	}
 	if token.RefreshToken == "" {
 		return nil, errors.New("unable to get RefreshToken. If you are upgrading from older versions of rclone, please run `rclone config` and re-configure this backend")
@@ -258,13 +264,13 @@ func NewFs(ctx context.Context, name, root string, m configmap.Mapper) (fs.Fs, e
 		token.TokenType = "OAuth"
 		err = oauthutil.PutToken(name, m, token, false)
 		if err != nil {
-			return nil, errors.Wrap(err, "couldn't save OAuth token")
+			return nil, fmt.Errorf("couldn't save OAuth token: %w", err)
 		}
 		log.Printf("Automatically upgraded OAuth config.")
 	}
 	oAuthClient, _, err := oauthutil.NewClient(ctx, name, m, oauthConfig)
 	if err != nil {
-		return nil, errors.Wrap(err, "failed to configure Yandex")
+		return nil, fmt.Errorf("failed to configure Yandex: %w", err)
 	}
 
 	ci := fs.GetConfig(ctx)
@@ -309,7 +315,7 @@ func (f *Fs) itemToDirEntry(ctx context.Context, remote string, object *api.Reso
 	case "dir":
 		t, err := time.Parse(time.RFC3339Nano, object.Modified)
 		if err != nil {
-			return nil, errors.Wrap(err, "error parsing time in directory item")
+			return nil, fmt.Errorf("error parsing time in directory item: %w", err)
 		}
 		d := fs.NewDir(remote, t).SetSize(object.Size)
 		return d, nil
@@ -560,19 +566,19 @@ func (f *Fs) waitForJob(ctx context.Context, location string) (err error) {
 		var status api.AsyncStatus
 		err = json.Unmarshal(body, &status)
 		if err != nil {
-			return errors.Wrapf(err, "async status result not JSON: %q", body)
+			return fmt.Errorf("async status result not JSON: %q: %w", body, err)
 		}
 
 		switch status.Status {
 		case "failure":
-			return errors.Errorf("async operation returned %q", status.Status)
+			return fmt.Errorf("async operation returned %q", status.Status)
 		case "success":
 			return nil
 		}
 
 		time.Sleep(1 * time.Second)
 	}
-	return errors.Errorf("async operation didn't complete after %v", f.ci.TimeoutOrInfinite())
+	return fmt.Errorf("async operation didn't complete after %v", f.ci.TimeoutOrInfinite())
 }
 
 func (f *Fs) delete(ctx context.Context, path string, hardDelete bool) (err error) {
@@ -607,7 +613,7 @@ func (f *Fs) delete(ctx context.Context, path string, hardDelete bool) (err erro
 		var info api.AsyncInfo
 		err = json.Unmarshal(body, &info)
 		if err != nil {
-			return errors.Wrapf(err, "async info result not JSON: %q", body)
+			return fmt.Errorf("async info result not JSON: %q: %w", body, err)
 		}
 		return f.waitForJob(ctx, info.HRef)
 	}
@@ -623,14 +629,14 @@ func (f *Fs) purgeCheck(ctx context.Context, dir string, check bool) error {
 		//send request to get list of objects in this directory.
 		info, err := f.readMetaDataForPath(ctx, root, &api.ResourceInfoRequestOptions{})
 		if err != nil {
-			return errors.Wrap(err, "rmdir failed")
+			return fmt.Errorf("rmdir failed: %w", err)
 		}
 		if len(info.Embedded.Items) != 0 {
 			return fs.ErrorDirectoryNotEmpty
 		}
 	}
 	//delete directory
-	return f.delete(ctx, root, false)
+	return f.delete(ctx, root, f.opt.HardDelete)
 }
 
 // Rmdir deletes the container
@@ -683,7 +689,7 @@ func (f *Fs) copyOrMove(ctx context.Context, method, src, dst string, overwrite
 		var info api.AsyncInfo
 		err = json.Unmarshal(body, &info)
 		if err != nil {
-			return errors.Wrapf(err, "async info result not JSON: %q", body)
+			return fmt.Errorf("async info result not JSON: %q: %w", body, err)
 		}
 		return f.waitForJob(ctx, info.HRef)
 	}
@@ -714,7 +720,7 @@ func (f *Fs) Copy(ctx context.Context, src fs.Object, remote string) (fs.Object,
 	err = f.copyOrMove(ctx, "copy", srcObj.filePath(), dstPath, false)
 
 	if err != nil {
-		return nil, errors.Wrap(err, "couldn't copy file")
+		return nil, fmt.Errorf("couldn't copy file: %w", err)
 	}
 
 	return f.NewObject(ctx, remote)
@@ -744,7 +750,7 @@ func (f *Fs) Move(ctx context.Context, src fs.Object, remote string) (fs.Object,
 	err = f.copyOrMove(ctx, "move", srcObj.filePath(), dstPath, false)
 
 	if err != nil {
-		return nil, errors.Wrap(err, "couldn't move file")
+		return nil, fmt.Errorf("couldn't move file: %w", err)
 	}
 
 	return f.NewObject(ctx, remote)
@@ -795,7 +801,7 @@ func (f *Fs) DirMove(ctx context.Context, src fs.Fs, srcRemote, dstRemote string
 	err = f.copyOrMove(ctx, "move", srcPath, dstPath, false)
 
 	if err != nil {
-		return errors.Wrap(err, "couldn't move directory")
+		return fmt.Errorf("couldn't move directory: %w", err)
 	}
 	return nil
 }
@@ -831,9 +837,9 @@ func (f *Fs) PublicLink(ctx context.Context, remote string, expire fs.Duration,
 	}
 	if err != nil {
 		if unlink {
-			return "", errors.Wrap(err, "couldn't remove public link")
+			return "", fmt.Errorf("couldn't remove public link: %w", err)
 		}
-		return "", errors.Wrap(err, "couldn't create public link")
+		return "", fmt.Errorf("couldn't create public link: %w", err)
 	}
 
 	info, err := f.readMetaDataForPath(ctx, f.filePath(remote), &api.ResourceInfoRequestOptions{})
@@ -934,7 +940,7 @@ func (o *Object) setMetaData(info *api.ResourceInfoResponse) (err error) {
 	}
 	t, err := time.Parse(time.RFC3339Nano, modTimeString)
 	if err != nil {
-		return errors.Wrapf(err, "failed to parse modtime from %q", modTimeString)
+		return fmt.Errorf("failed to parse modtime from %q: %w", modTimeString, err)
 	}
 	o.modTime = t
 	return nil
@@ -1141,7 +1147,7 @@ func (o *Object) Update(ctx context.Context, in io.Reader, src fs.ObjectInfo, op
 
 // Remove an object
 func (o *Object) Remove(ctx context.Context) error {
-	return o.fs.delete(ctx, o.filePath(), false)
+	return o.fs.delete(ctx, o.filePath(), o.fs.opt.HardDelete)
 }
 
 // MimeType of an Object if known, "" otherwise
