@@ -7,7 +7,6 @@ import (
 	"os"
 	"sort"
 
-	"github.com/pkg/errors"
 	"github.com/rclone/rclone/cmd"
 	"github.com/rclone/rclone/cmd/rc"
 	"github.com/rclone/rclone/fs"
@@ -30,9 +29,9 @@ func init() {
 
 var commandDefinition = &cobra.Command{
 	Use:   "backend <command> remote:path [opts] <args>",
-	Short: `Run a backend specific command.`,
+	Short: `Run a backend-specific command.`,
 	Long: `
-This runs a backend specific command. The commands themselves (except
+This runs a backend-specific command. The commands themselves (except
 for "help" and "features") are defined by the backends and you should
 see the backend docs for definitions.
 
@@ -42,7 +41,7 @@ You can discover what commands a backend implements by using
     rclone backend help <backendname>
 
 You can also discover information about the backend using (see
-[operations/fsinfo](/rc/#operations/fsinfo) in the remote control docs
+[operations/fsinfo](/rc/#operations-fsinfo) in the remote control docs
 for more info).
 
     rclone backend features remote:
@@ -56,7 +55,7 @@ Pass arguments to the backend by placing them on the end of the line
     rclone backend cleanup remote:path file1 file2 file3
 
 Note to run these commands on a running backend then see
-[backend/command](/rc/#backend/command) in the rc docs.
+[backend/command](/rc/#backend-command) in the rc docs.
 `,
 	RunE: func(command *cobra.Command, args []string) error {
 		cmd.CheckArgs(2, 1e6, command, args)
@@ -88,14 +87,14 @@ Note to run these commands on a running backend then see
 			default:
 				doCommand := f.Features().Command
 				if doCommand == nil {
-					return errors.Errorf("%v: doesn't support backend commands", f)
+					return fmt.Errorf("%v: doesn't support backend commands", f)
 				}
 				arg := args[2:]
 				opt := rc.ParseOptions(options)
 				out, err = doCommand(context.Background(), name, arg, opt)
 			}
 			if err != nil {
-				return errors.Wrapf(err, "command %q failed", name)
+				return fmt.Errorf("command %q failed: %w", name, err)
 
 			}
 			// Output the result
@@ -121,7 +120,7 @@ Note to run these commands on a running backend then see
 				enc.SetIndent("", "\t")
 				err = enc.Encode(out)
 				if err != nil {
-					return errors.Wrap(err, "failed to write JSON")
+					return fmt.Errorf("failed to write JSON: %w", err)
 				}
 			}
 			return nil
@@ -135,7 +134,7 @@ func showHelp(fsInfo *fs.RegInfo) error {
 	cmds := fsInfo.CommandHelp
 	name := fsInfo.Name
 	if len(cmds) == 0 {
-		return errors.Errorf("%s backend has no commands", name)
+		return fmt.Errorf("%s backend has no commands", name)
 	}
 	fmt.Printf("## Backend commands\n\n")
 	fmt.Printf(`Here are the commands specific to the %s backend.
@@ -150,7 +149,7 @@ See [the "rclone backend" command](/commands/rclone_backend/) for more
 info on how to pass options and arguments.
 
 These can be run on a running backend using the rc command
-[backend/command](/rc/#backend/command).
+[backend/command](/rc/#backend-command).
 
 `, name)
 	for _, cmd := range cmds {
