@@ -26,11 +26,11 @@ var (
 func init() {
 	cmd.Root.AddCommand(commandDefinition)
 	cmdFlags := commandDefinition.Flags()
-	flags.Int64VarP(cmdFlags, &head, "head", "", head, "Only print the first N characters.")
-	flags.Int64VarP(cmdFlags, &tail, "tail", "", tail, "Only print the last N characters.")
-	flags.Int64VarP(cmdFlags, &offset, "offset", "", offset, "Start printing at offset N (or from end if -ve).")
-	flags.Int64VarP(cmdFlags, &count, "count", "", count, "Only print N characters.")
-	flags.BoolVarP(cmdFlags, &discard, "discard", "", discard, "Discard the output instead of printing.")
+	flags.Int64VarP(cmdFlags, &head, "head", "", head, "Only print the first N characters")
+	flags.Int64VarP(cmdFlags, &tail, "tail", "", tail, "Only print the last N characters")
+	flags.Int64VarP(cmdFlags, &offset, "offset", "", offset, "Start printing at offset N (or from end if -ve)")
+	flags.Int64VarP(cmdFlags, &count, "count", "", count, "Only print N characters")
+	flags.BoolVarP(cmdFlags, &discard, "discard", "", discard, "Discard the output instead of printing")
 }
 
 var commandDefinition = &cobra.Command{
