@@ -17,15 +17,15 @@ There are several related list commands
   * |lsf| to list objects and directories in easy to parse format
   * |lsjson| to list objects and directories in JSON format
 
-|ls|,|lsl|,|lsd| are designed to be human readable.
-|lsf| is designed to be human and machine readable.
-|lsjson| is designed to be machine readable.
+|ls|,|lsl|,|lsd| are designed to be human-readable.
+|lsf| is designed to be human and machine-readable.
+|lsjson| is designed to be machine-readable.
 
 Note that |ls| and |lsl| recurse by default - use |--max-depth 1| to stop the recursion.
 
 The other list commands |lsd|,|lsf|,|lsjson| do not recurse by default - use |-R| to make them recurse.
 
-Listing a non existent directory will produce an error except for
+Listing a non-existent directory will produce an error except for
 remotes which can't have empty directories (e.g. s3, swift, or gcs -
-the bucket based remotes).
+the bucket-based remotes).
 `, "|", "`")
