@@ -18,24 +18,22 @@ import (
 	"sync"
 	"time"
 
-	"github.com/rclone/rclone/fs/rc/webgui"
-
-	"github.com/pkg/errors"
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
-	"github.com/skratchdot/open-golang/open"
-
 	"github.com/rclone/rclone/cmd/serve/httplib"
 	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/fs/accounting"
 	"github.com/rclone/rclone/fs/cache"
 	"github.com/rclone/rclone/fs/config"
+	"github.com/rclone/rclone/fs/fshttp"
 	"github.com/rclone/rclone/fs/list"
 	"github.com/rclone/rclone/fs/rc"
 	"github.com/rclone/rclone/fs/rc/jobs"
 	"github.com/rclone/rclone/fs/rc/rcflags"
+	"github.com/rclone/rclone/fs/rc/webgui"
 	"github.com/rclone/rclone/lib/http/serve"
 	"github.com/rclone/rclone/lib/random"
+	"github.com/skratchdot/open-golang/open"
 )
 
 var promHandler http.Handler
@@ -44,6 +42,13 @@ var onlyOnceWarningAllowOrigin sync.Once
 func init() {
 	rcloneCollector := accounting.NewRcloneCollector(context.Background())
 	prometheus.MustRegister(rcloneCollector)
+
+	m := fshttp.NewMetrics("rclone")
+	for _, c := range m.Collectors() {
+		prometheus.MustRegister(c)
+	}
+	fshttp.DefaultMetrics = m
+
 	promHandler = promhttp.Handler()
 }
 
@@ -87,23 +92,23 @@ func newServer(ctx context.Context, opt *rc.Options, mux *http.ServeMux) *Server
 		fileHandler = http.FileServer(http.Dir(opt.Files))
 	} else if opt.WebUI {
 		if err := webgui.CheckAndDownloadWebGUIRelease(opt.WebGUIUpdate, opt.WebGUIForceUpdate, opt.WebGUIFetchURL, config.GetCacheDir()); err != nil {
-			log.Fatalf("Error while fetching the latest release of Web GUI: %v", err)
+			fs.Errorf(nil, "Error while fetching the latest release of Web GUI: %v", err)
 		}
 		if opt.NoAuth {
-			opt.NoAuth = false
-			fs.Infof(nil, "Cannot run Web GUI without authentication, using default auth")
-		}
-		if opt.HTTPOptions.BasicUser == "" {
-			opt.HTTPOptions.BasicUser = "gui"
-			fs.Infof(nil, "No username specified. Using default username: %s \n", rcflags.Opt.HTTPOptions.BasicUser)
-		}
-		if opt.HTTPOptions.BasicPass == "" {
-			randomPass, err := random.Password(128)
-			if err != nil {
-				log.Fatalf("Failed to make password: %v", err)
+			fs.Logf(nil, "It is recommended to use web gui with auth.")
+		} else {
+			if opt.HTTPOptions.BasicUser == "" {
+				opt.HTTPOptions.BasicUser = "gui"
+				fs.Infof(nil, "No username specified. Using default username: %s \n", rcflags.Opt.HTTPOptions.BasicUser)
+			}
+			if opt.HTTPOptions.BasicPass == "" {
+				randomPass, err := random.Password(128)
+				if err != nil {
+					log.Fatalf("Failed to make password: %v", err)
+				}
+				opt.HTTPOptions.BasicPass = randomPass
+				fs.Infof(nil, "No password specified. Using random password: %s \n", randomPass)
 			}
-			opt.HTTPOptions.BasicPass = randomPass
-			fs.Infof(nil, "No password specified. Using random password: %s \n", randomPass)
 		}
 		opt.Serve = true
 
@@ -138,7 +143,7 @@ func (s *Server) Serve() error {
 	if s.files != nil {
 		openURL, err := url.Parse(s.URL())
 		if err != nil {
-			return errors.Wrap(err, "invalid serving URL")
+			return fmt.Errorf("invalid serving URL: %w", err)
 		}
 		// Add username, password into the URL if they are set
 		user, pass := s.opt.HTTPOptions.BasicUser, s.opt.HTTPOptions.BasicPass
@@ -211,7 +216,7 @@ func (s *Server) handler(w http.ResponseWriter, r *http.Request) {
 	case "GET", "HEAD":
 		s.handleGet(w, r, path)
 	default:
-		writeError(path, nil, w, errors.Errorf("method %q not allowed", r.Method), http.StatusMethodNotAllowed)
+		writeError(path, nil, w, fmt.Errorf("method %q not allowed", r.Method), http.StatusMethodNotAllowed)
 		return
 	}
 }
@@ -225,7 +230,7 @@ func (s *Server) handlePost(w http.ResponseWriter, r *http.Request, path string)
 		// Parse the POST and URL parameters into r.Form, for others r.Form will be empty value
 		err := r.ParseForm()
 		if err != nil {
-			writeError(path, nil, w, errors.Wrap(err, "failed to parse form/URL parameters"), http.StatusBadRequest)
+			writeError(path, nil, w, fmt.Errorf("failed to parse form/URL parameters: %w", err), http.StatusBadRequest)
 			return
 		}
 		values = r.Form
@@ -243,20 +248,20 @@ func (s *Server) handlePost(w http.ResponseWriter, r *http.Request, path string)
 	if contentType == "application/json" {
 		err := json.NewDecoder(r.Body).Decode(&in)
 		if err != nil {
-			writeError(path, in, w, errors.Wrap(err, "failed to read input JSON"), http.StatusBadRequest)
+			writeError(path, in, w, fmt.Errorf("failed to read input JSON: %w", err), http.StatusBadRequest)
 			return
 		}
 	}
 	// Find the call
 	call := rc.Calls.Get(path)
 	if call == nil {
-		writeError(path, in, w, errors.Errorf("couldn't find method %q", path), http.StatusNotFound)
+		writeError(path, in, w, fmt.Errorf("couldn't find method %q", path), http.StatusNotFound)
 		return
 	}
 
 	// Check to see if it requires authorisation
 	if !s.opt.NoAuth && call.AuthRequired && !s.UsingAuth() {
-		writeError(path, in, w, errors.Errorf("authentication must be set up on the rc server to use %q or the --rc-no-auth flag must be in use", path), http.StatusForbidden)
+		writeError(path, in, w, fmt.Errorf("authentication must be set up on the rc server to use %q or the --rc-no-auth flag must be in use", path), http.StatusForbidden)
 		return
 	}
 
@@ -317,14 +322,14 @@ func (s *Server) serveRoot(w http.ResponseWriter, r *http.Request) {
 func (s *Server) serveRemote(w http.ResponseWriter, r *http.Request, path string, fsName string) {
 	f, err := cache.Get(s.ctx, fsName)
 	if err != nil {
-		writeError(path, nil, w, errors.Wrap(err, "failed to make Fs"), http.StatusInternalServerError)
+		writeError(path, nil, w, fmt.Errorf("failed to make Fs: %w", err), http.StatusInternalServerError)
 		return
 	}
 	if path == "" || strings.HasSuffix(path, "/") {
 		path = strings.Trim(path, "/")
 		entries, err := list.DirSorted(r.Context(), f, false, path)
 		if err != nil {
-			writeError(path, nil, w, errors.Wrap(err, "failed to list directory"), http.StatusInternalServerError)
+			writeError(path, nil, w, fmt.Errorf("failed to list directory: %w", err), http.StatusInternalServerError)
 			return
 		}
 		// Make the entries for display
@@ -343,7 +348,7 @@ func (s *Server) serveRemote(w http.ResponseWriter, r *http.Request, path string
 		path = strings.Trim(path, "/")
 		o, err := f.NewObject(r.Context(), path)
 		if err != nil {
-			writeError(path, nil, w, errors.Wrap(err, "failed to find object"), http.StatusInternalServerError)
+			writeError(path, nil, w, fmt.Errorf("failed to find object: %w", err), http.StatusInternalServerError)
 			return
 		}
 		serve.Object(w, r, o)
